@@ -131,13 +131,6 @@ typedef unsigned char uchar;
 #error "SSLeay versions below 0.8.0 are not supported"
 #endif
 
-/* 
- * Define this to TRUE to debug the SSL verification
- * or the SSL session caching stuff
- */
-#define DEBUG_VERIFY    FALSE
-#define DEBUG_SESSIONS  FALSE
-
 /*
  * Correct a typo in SSLeay 
  */
@@ -179,9 +172,6 @@ typedef struct {
 
 /*
  * Define the mod_ssl per-directory configuration structure 
- * 1) If cipher is banned, refuse 
- * 2) If RequiredCiphers is NULL, accept 
- * 3) If the cipher isn't required, refuse 
  */
 typedef struct {
     table *tbRequiredCiphers;
@@ -222,6 +212,7 @@ static const char  *cmd_SSLVerifyClient(cmd_parms *, char *, char *);
 static void         init_Module(server_rec *, pool *);
 static void         init_SSLeay(server_rec *, pool *);
 static void         init_GetCertAndKey(server_rec *, pool *, SSLConfigRec *);
+static void         init_GetPrivateKey(server_rec *, pool *, SSLConfigRec *, const char *);
 static int          init_VerifyFlags(SSLConfigRec *);
 
 /*  Apache API hooks  */
